@@ -1,19 +1,7 @@
-/* This file is part of StepCore library.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   StepCore library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   StepCore library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with StepCore; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 /** \file spring.h
@@ -46,7 +34,7 @@ class SpringErrors: public ObjectErrors
 
 public:
     /** Constructs SpringErrors */
-    explicit SpringErrors(Item* owner = NULL)
+    explicit SpringErrors(Item* owner = nullptr)
         : ObjectErrors(owner), _restLengthVariance(0), _stiffnessVariance(0),
           _dampingVariance(0), _localPosition1Variance(0,0), _localPosition2Variance(0,0) {}
 
@@ -133,7 +121,7 @@ class Spring : public Force
 public:
     /** Constructs Spring */
     explicit Spring(double restLength = 0, double stiffness = 1, double damping = 0,
-                Item* body1 = 0, Item* body2 = 0);
+                Item* body1 = nullptr, Item* body2 = nullptr);
 
     void calcForce(bool calcVariances) override;
 
